<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>LockScreen</name>
    <message>
        <location filename="../screenlocker/qml/LockScreen.qml" line="202"/>
        <source>Password</source>
        <translation>Senha</translation>
    </message>
    <message>
        <location filename="../screenlocker/qml/LockScreen.qml" line="225"/>
        <source>Unlock</source>
        <translation>Desbloquear</translation>
    </message>
    <message>
        <location filename="../screenlocker/qml/LockScreen.qml" line="274"/>
        <source>Please enter your password</source>
        <translation>Por favor, insira sua senha</translation>
    </message>
    <message>
        <location filename="../screenlocker/qml/LockScreen.qml" line="284"/>
        <source>Unlocking failed</source>
        <translation>O desbloqueio falhou</translation>
    </message>
</context>
</TS>
